@@ -64,10 +64,12 @@ database.DDL.emuDB_items = 'CREATE TABLE items (
   sample_point INTEGER,
   sample_start INTEGER,
   sample_dur INTEGER,
-  PRIMARY KEY (db_uuid, session, bundle, level, item_id, type),
+  PRIMARY KEY (db_uuid, session, bundle, item_id),
   FOREIGN KEY (db_uuid, session, bundle) REFERENCES bundle(db_uuid, session, name) ON DELETE CASCADE
 );'
 
+# database.DDL.emuDB_items_idx1 = 'CREATE INDEX IF NOT EXISTS items_idx1 ON items(item_id, bundle, session, db_uuid)'
+
 # Important note:
 # The primary key of items contains more columns then needed to identify a particular item.
 # PRIMARY KEY (db_uuid,session,bundle,item_id) would be sufficient but the extended primary key 
@@ -84,9 +86,12 @@ database.DDL.emuDB_labels = 'CREATE TABLE labels (
   label_idx INTEGER,
   name TEXT,
   label TEXT,
+  PRIMARY KEY (db_uuid, session, bundle, item_id, label_idx),
   FOREIGN KEY (db_uuid, session, bundle) REFERENCES bundle(db_uuid, session, name) ON DELETE CASCADE
 );'
 
+# database.DDL.emuDB_labels_idx1 = 'CREATE INDEX IF NOT EXISTS labels_idx1 ON labels(item_id, bundle, session, db_uuid)'
+
 database.DDL.emuDB_links = 'CREATE TABLE links (
   db_uuid VARCHAR(36) NOT NULL,
   session TEXT,
@@ -96,7 +101,9 @@ database.DDL.emuDB_links = 'CREATE TABLE links (
   label TEXT,
   FOREIGN KEY (db_uuid, session, bundle) REFERENCES bundle(db_uuid, session, name) ON DELETE CASCADE
 );'
-database.DDL.emuDB_linksIdx = 'CREATE INDEX links_idx ON links(db_uuid,session,bundle,from_id,to_id)'
+
+database.DDL.emuDB_links_both_ids_idx = 'CREATE INDEX IF NOT EXISTS links_both_ids_idx ON links(db_uuid, session, bundle, from_id, to_id)'
+database.DDL.emuDB_links_to_id_idx = 'CREATE INDEX IF NOT EXISTS links_to_id_idx ON links(db_uuid, session, bundle, to_id)'
 
 database.DDL.emuDB_linksTmp = 'CREATE TEMP TABLE links_tmp (
   db_uuid VARCHAR(36) NOT NULL,
@@ -106,7 +113,8 @@ database.DDL.emuDB_linksTmp = 'CREATE TEMP TABLE links_tmp (
   to_id INTEGER,
   label TEXT
 );'
-database.DDL.emuDB_linksTmpIdx = 'CREATE INDEX links_tmp_idx ON links_tmp(db_uuid,session,bundle,from_id,to_id)'
+
+database.DDL.emuDB_linksTmpIdx = 'CREATE INDEX IF NOT EXISTS links_tmp_idx ON links_tmp(db_uuid, session, bundle, from_id, to_id)'
 
 database.DDL.emuDB_linksExt = 'CREATE TABLE links_ext (
   db_uuid VARCHAR(36) NOT NULL,
@@ -124,7 +132,7 @@ database.DDL.emuDB_linksExt = 'CREATE TABLE links_ext (
 );'
 
 
-database.DDL.emuDB_linksExtIdx = 'CREATE INDEX links_ext_idx ON links_ext(db_uuid,session,bundle,from_id,to_id,to_level,type)'
+database.DDL.emuDB_linksExtIdx = 'CREATE INDEX IF NOT EXISTS links_ext_idx ON links_ext(db_uuid,session,bundle,from_id,to_id,to_level,type)'
 
 # this should be a temp table
 database.DDL.emuDB_linksExtTmp = 'CREATE TEMP TABLE links_ext_tmp (
@@ -140,7 +148,8 @@ database.DDL.emuDB_linksExtTmp = 'CREATE TEMP TABLE links_ext_tmp (
   to_seq_len INTEGER,
   label TEXT
 );'
-database.DDL.emuDB_linksExtTmpIdx = 'CREATE INDEX links_ext_tmp_idx ON links_ext_tmp(db_uuid,session,bundle,from_id,to_id,to_level,type)'
+
+database.DDL.emuDB_linksExtTmpIdx = 'CREATE INDEX IF NOT EXISTS links_ext_tmp_idx ON links_ext_tmp(db_uuid,session,bundle,from_id,to_id,to_level,type)'
 
 # this should be a temp table
 database.DDL.emuDB_linksExtTmp2 = 'CREATE TEMP TABLE links_ext_tmp2 (
@@ -157,7 +166,7 @@ database.DDL.emuDB_linksExtTmp2 = 'CREATE TEMP TABLE links_ext_tmp2 (
   label TEXT
 );'
 
-database.DDL.emuDB_linksExtTmpIdx2 = 'CREATE INDEX links_ext_tmp2_idx ON links_ext_tmp2(db_uuid,session,bundle,from_id,to_id,to_level,type)'
+database.DDL.emuDB_linksExtTmpIdx2 = 'CREATE INDEX IF NOT EXISTS links_ext_tmp2_idx ON links_ext_tmp2(db_uuid,session,bundle,from_id,to_id,to_level,type)'
 
 ####################################
 ######### DBI functions ############
@@ -191,16 +200,18 @@ initialize_emuDbDBI <- function(emuDBhandle, createTables=TRUE, createIndices=TR
     DBI::dbGetQuery(emuDBhandle$connection, database.DDL.emuDB_labels)
     DBI::dbGetQuery(emuDBhandle$connection, database.DDL.emuDB_links)
     DBI::dbGetQuery(emuDBhandle$connection, database.DDL.emuDB_linksExt)
-    if(createIndices){  
-      create_emuDBindicesDBI(emuDBhandle)
-    }
+  }
+  if(createIndices){
+    create_emuDBindicesDBI(emuDBhandle)
   }
 }
 
 create_emuDBindicesDBI<-function(emuDBhandle){
-  
-  DBI::dbGetQuery(emuDBhandle$connection, database.DDL.emuDB_linksIdx) 
-  DBI::dbGetQuery(emuDBhandle$connection, database.DDL.emuDB_linksExtIdx) 
+  DBI::dbGetQuery(emuDBhandle$connection, database.DDL.emuDB_links_both_ids_idx)
+  DBI::dbGetQuery(emuDBhandle$connection, database.DDL.emuDB_links_to_id_idx)
+  # DBI::dbGetQuery(emuDBhandle$connection, database.DDL.emuDB_labels_idx1)
+  # DBI::dbGetQuery(emuDBhandle$connection, database.DDL.emuDB_linksIdx)
+  DBI::dbGetQuery(emuDBhandle$connection, database.DDL.emuDB_linksExtIdx)
 }
 
 
@@ -542,9 +553,13 @@ list_sessions <- function(emuDBhandle){
 ##' 
 list_bundles <- function(emuDBhandle, session=NULL){
   sesDf = list_sessions(emuDBhandle)
+  if(!is.null(session)){
+    sesDf = dplyr::filter_(sesDf, ~(name == session))
+  }
   bndlPattern = paste0("^.*", bundle.dir.suffix ,"$")
   res = data.frame(session = character(), name = character(), stringsAsFactors = F)
   
+  
   for(ses in sesDf$name){
     bndlDirs = dir(file.path(emuDBhandle$basePath, paste0(ses, session.suffix)), pattern = bndlPattern)
     bndlNames = gsub(paste0(bundle.dir.suffix, "$"), "", bndlDirs)
@@ -762,6 +777,7 @@ create_emuDB<-function(name, targetDir, mediaFileExtension='wav',
 ##' use an SQLite database either in memory (\code{inMemoryCache = TRUE}) or in the emuDB folder. This is intended
 ##' for expert use only!
 ##' @param verbose be verbose
+##' @param ... additional parameters
 ##' @return name of emuDB
 ##' @import jsonlite DBI
 ##' @export
@@ -784,7 +800,7 @@ create_emuDB<-function(name, targetDir, mediaFileExtension='wav',
 ##' ae = load_emuDB(demoDatabaseDir)
 ##' 
 ##' }
-load_emuDB <- function(databaseDir, inMemoryCache = FALSE, connection = NULL, verbose=TRUE){
+load_emuDB <- function(databaseDir, inMemoryCache = FALSE, connection = NULL, verbose=TRUE, ...){
   progress = 0
   # check database dir
   if(!file.exists(databaseDir)){
@@ -810,6 +826,13 @@ load_emuDB <- function(databaseDir, inMemoryCache = FALSE, connection = NULL, ve
   if(!file.exists(dbCfgPath)){
     stop("Could not find database info file: ",dbCfgPath,"\n")
   }
+  # extract ... (ellipsis) parameters
+  dots = list(...)
+  if("update_cache" %in% names(dots)){
+    updateCache = dots$update_cache
+  }else{
+    updateCache = T
+  }
   
   # load DBconfig
   DBconfig = jsonlite::fromJSON(dbCfgPath, simplifyVector=FALSE)
@@ -834,7 +857,9 @@ load_emuDB <- function(databaseDir, inMemoryCache = FALSE, connection = NULL, ve
   # check if cache exist -> update cache if true
   dbsDf = get_emuDbDBI(dbHandle)
   if(nrow(dbsDf)>0){
-    update_cache(dbHandle, verbose = verbose)
+    if(updateCache){
+      update_cache(dbHandle, verbose = verbose)
+    }
     return(dbHandle)
   }
   
@@ -900,6 +925,8 @@ load_emuDB <- function(databaseDir, inMemoryCache = FALSE, connection = NULL, ve
     # build redundat links and calc positions
     if(verbose){ 
       cat("\nbuilding redundant links and position of links... (this may take a while)\n")
+    }else{
+      cat("\n")
     }
     
     build_allRedundantLinks(dbHandle)
